Для 27 версии

корневые страницы формы
0.0.1.2.1.1.20
0.1.10 версия форм, инкрементируется при каждом изменении

# Расположение элементов
Элементы разбиты по панеляем.

Все элементы со всех страниц панели идут плоским списком.

Привязка к странице указана внутри элемента (у деволтной метки это 3.20), нумерация страниц с 0.

Каждый элемент в зависимости от типа может быть указан в 4 "оглавлениях" которые идут перед списком страниц.
Их структура не понятна. 4 списка которые содержат id элемента и какое то число.


Структура вложенной панели в части описания страниц и элементов практически идентична.

#Привязки
Привязки описываются на самом элементе, кроме этого на элеменете к которому
они прявзяны так же дублируется информация кто к нему привязан по
каждой из сторон отдельно

6 групп элементов для описания стороны которая привязана

* 0 - хз
  * 2 - хз
  * id элемента к чему привязан или -1
  * как привязан
     * 0 - верхяя
     * 1 - нижняя
     * 2 - левая
     * 3 - правая
     * 4 - центр по вертикали
     * 5 - центр по горизонтали
     * 6 - нет
  * хз - похоже какая координата


Привязи хранятся в рамках одной панели
##Информация кто привязан к элементу
3.12 для элемента
2 для панели

4-6 массивов друг за другом

* 0 верхняя
* 1 нижняя или центр
* 2 левой
* 3 правая
структура привязки
* 0 - ?
* ид элемента
* по какой границе
    * 0 верхняя
    * 1 нижняя или центр
    * 2 левой
    * 3 правая
    


3 - лево
4 - право



# Порядок следования страниц

Список страниц не меняется, их порядковый номер используется в описании элемента.

Порядок следования страниц описан отдельно - отступ 4 элемента от списка страниц.

На каждую страницу по 4 записи в порядке страниц (хз).

Порядок следования страницы в 5 элементе.




элементы ввода описываются в трех местах
0.2.2 
* описание элемент
* список элементов вввода
* какой то их перечень по порядку